@@ -44,6 +44,7 @@
 #include <osmocom/bsc/ctrl.h>
 #include <osmocom/bsc/handover_ctrl.h>
 #include <osmocom/bsc/neighbor_ident.h>
+#include <osmocom/bsc/sigtran_compat.h>
 
 static int verify_net_apply_config_file(struct ctrl_cmd *cmd, const char *value, void *_data)
 {
@@ -632,33 +633,21 @@ static int msc_signal_handler(unsigned int subsys, unsigned int signal,
 static struct osmo_ss7_as *msc_get_ss7_as(struct bsc_msc_data *msc)
 {
 	struct osmo_ss7_route *rt;
+	struct osmo_ss7_as *as;
 	struct osmo_ss7_instance *ss7 = osmo_sccp_get_ss7(msc->a.sccp);
 	rt = osmo_ss7_route_lookup(ss7, msc->a.msc_addr.pc);
 	if (!rt)
 		return NULL;
-	return rt->dest.as;
-}
-
-static int _ss7_as_send(struct osmo_ss7_as *as, struct msgb *msg)
-{
-	struct osmo_ss7_asp *asp;
-	unsigned int i;
-
-	/* FIXME: unify with xua_as_transmit_msg() and perform proper ASP lookup */
-	for (i = 0; i < ARRAY_SIZE(as->cfg.asps); i++) {
-		asp = as->cfg.asps[i];
-		if (!asp)
-			continue;
-		/* FIXME: deal with multiple ASPs per AS */
-		return osmo_ss7_asp_send(asp, msg);
-	}
-	msgb_free(msg);
-	return -1;
+	as = osmo_ss7_route_get_dest_as(rt);
+	if (!as)
+		return NULL;
+	return as;
 }
 
 int bsc_sccplite_msc_send(struct bsc_msc_data *msc, struct msgb *msg)
 {
 	struct osmo_ss7_as *as;
+	struct osmo_ss7_asp *asp;
 
 	as = msc_get_ss7_as(msc);
 	if (!as) {
@@ -667,10 +656,18 @@ int bsc_sccplite_msc_send(struct bsc_msc_data *msc, struct msgb *msg)
 	}
 
 	/* don't attempt to send CTRL on a non-SCCPlite AS */
-	if (as->cfg.proto != OSMO_SS7_ASP_PROT_IPA)
+	if (osmo_ss7_as_get_asp_protocol(as) != OSMO_SS7_ASP_PROT_IPA) {
+		msgb_free(msg);
 		return 0;
+	}
 
-	return _ss7_as_send(as, msg);
+	asp = osmo_ss7_as_select_asp(as);
+	if (!asp) {
+		LOGP(DCTRL, LOGL_NOTICE, "No ASP found for AS, dropping message\n");
+		msgb_free(msg);
+		return -1;
+	}
+	return osmo_ss7_asp_send(asp, msg);
 }
 
 /* Encode a CTRL command and send it to the given ASP
