@@ -32,6 +32,7 @@
 #include <osmocom/bsc/lcs_loc_req.h>
 #include <osmocom/bsc/bssmap_reset.h>
 #include <osmocom/bsc/gsm_data.h>
+#include <osmocom/bsc/sigtran_compat.h>
 
 /* Send reset to SMLC */
 int bssmap_le_tx_reset(void)
@@ -209,8 +210,9 @@ static int sccp_sap_up(struct osmo_prim_hdr *oph, void *_scu)
 		break;
 
 	default:
-		LOGP(DLCS, LOGL_ERROR, "Unhandled SIGTRAN operation %s on primitive %u\n",
-		     get_value_string(osmo_prim_op_names, oph->operation), oph->primitive);
+		LOGP(DLCS, LOGL_ERROR, "Unhandled SIGTRAN primitive %s.%s\n",
+		     osmo_scu_prim_type_name(oph->primitive),
+		     get_value_string(osmo_prim_op_names, oph->operation));
 		break;
 	}
 
@@ -449,13 +451,13 @@ static int lb_start(void)
 					   OSMO_SCCP_SSN_SMLC_BSSAP_LE);
 
 	/* Set up SCCP user and one ASP+AS */
-	snprintf(inst_name, sizeof(inst_name), "Lb-%u-%s", cs7_inst->cfg.id, osmo_ss7_asp_protocol_name(used_proto));
+	snprintf(inst_name, sizeof(inst_name), "Lb-%u-%s", bsc_gsmnet->smlc->cs7_instance, osmo_ss7_asp_protocol_name(used_proto));
 	LOGP(DLCS, LOGL_NOTICE, "Initializing SCCP connection for Lb/%s on cs7 instance %u\n",
-	     osmo_ss7_asp_protocol_name(used_proto), cs7_inst->cfg.id);
+	     osmo_ss7_asp_protocol_name(used_proto), bsc_gsmnet->smlc->cs7_instance);
 
 	/* SS7 Protocol stack */
 	default_pc = osmo_ss7_pointcode_parse(NULL, BSC_DEFAULT_PC);
-	sccp = osmo_sccp_simple_client_on_ss7_id(tall_bsc_ctx, cs7_inst->cfg.id, inst_name,
+	sccp = osmo_sccp_simple_client_on_ss7_id(tall_bsc_ctx, bsc_gsmnet->smlc->cs7_instance, inst_name,
 						 default_pc, used_proto,
 						 0, DEFAULT_ASP_LOCAL_IP,
 						 0, DEFAULT_ASP_REMOTE_IP);
@@ -617,18 +619,20 @@ static void enforce_ssn(struct vty *vty, struct osmo_sccp_addr *addr, enum osmo_
 bool smlc_set_cs7_instance(struct vty *vty, const char *from_vty_cmd, const char *from_addr,
 			   struct osmo_ss7_instance *ss7)
 {
+	uint32_t ss7_id = osmo_ss7_instance_get_id(ss7);
+
 	if (bsc_gsmnet->smlc->cs7_instance_valid) {
-		if (bsc_gsmnet->smlc->cs7_instance != ss7->cfg.id) {
+		if (bsc_gsmnet->smlc->cs7_instance != ss7_id) {
 			LOGP(DLCS, LOGL_ERROR,
 			     "%s: expecting address from cs7 instance %u, but '%s' is from %u\n",
-			     from_vty_cmd, bsc_gsmnet->smlc->cs7_instance, from_addr, ss7->cfg.id);
+			     from_vty_cmd, bsc_gsmnet->smlc->cs7_instance, from_addr, ss7_id);
 			vty_out(vty, "Error:"
 				" %s: expecting address from cs7 instance %u, but '%s' is from %u%s",
-				from_vty_cmd, bsc_gsmnet->smlc->cs7_instance, from_addr, ss7->cfg.id, VTY_NEWLINE);
+				from_vty_cmd, bsc_gsmnet->smlc->cs7_instance, from_addr, ss7_id, VTY_NEWLINE);
 			return false;
 		}
 	} else {
-		bsc_gsmnet->smlc->cs7_instance = ss7->cfg.id;
+		bsc_gsmnet->smlc->cs7_instance = ss7_id;
 		bsc_gsmnet->smlc->cs7_instance_valid = true;
 		LOGP(DLCS, LOGL_NOTICE, "Lb interface is using cs7 instance %u\n", bsc_gsmnet->smlc->cs7_instance);
 	}
