@@ -112,7 +112,7 @@ void fake_time_passes(time_t secs, suseconds_t usecs)
 	osmo_timers_update();
 }
 
-void fake_time_start()
+void fake_time_start(void)
 {
 	struct timespec *clock_override;
 
@@ -1522,7 +1522,7 @@ DEFUN(wait, wait_cmd,
 	return CMD_SUCCESS;
 }
 
-static void ho_test_vty_init()
+static void ho_test_vty_init(void)
 {
 	install_element(CONFIG_NODE, &create_n_bts_cmd);
 	install_element(CONFIG_NODE, &create_bts_cmd);
@@ -1687,11 +1687,6 @@ int main(int argc, char **argv)
 	bsc_vty_init(bsc_gsmnet);
 	ho_test_vty_init();
 
-	lchan_fsm_init();
-	bsc_subscr_conn_fsm_init();
-	handover_fsm_init();
-	assignment_fsm_init();
-
 	ho_set_algorithm(bsc_gsmnet->ho, 2);
 	ho_set_ho_active(bsc_gsmnet->ho, true);
 	ho_set_hodec2_as_active(bsc_gsmnet->ho, true);
@@ -1745,15 +1740,27 @@ void trau_recv_lchan() {}
 void trau_send_frame() {}
 /* Stub */
 int osmo_bsc_sigtran_open_conn(struct gsm_subscriber_connection *conn, struct msgb *msg) { return 0; }
-void bsc_sapi_n_reject(struct gsm_subscriber_connection *conn, uint8_t dlci, enum gsm0808_cause cause) {}
-void bsc_cipher_mode_compl(struct gsm_subscriber_connection *conn, struct msgb *msg, uint8_t chosen_a5_n) {}
-int bsc_compl_l3(struct gsm_lchan *lchan, struct msgb *msg, uint16_t chosen_channel)
+
+void __real_bsc_sapi_n_reject(struct gsm_subscriber_connection *conn, uint8_t dlci, enum gsm0808_cause cause);
+void __wrap_bsc_sapi_n_reject(struct gsm_subscriber_connection *conn, uint8_t dlci, enum gsm0808_cause cause) {}
+
+void __real_bsc_cipher_mode_compl(struct gsm_subscriber_connection *conn, struct msgb *msg, uint8_t chosen_a5_n);
+void __wrap_bsc_cipher_mode_compl(struct gsm_subscriber_connection *conn, struct msgb *msg, uint8_t chosen_a5_n) {}
+
+int __real_bsc_compl_l3(struct gsm_lchan *lchan, struct msgb *msg, uint16_t chosen_channel);
+int __wrap_bsc_compl_l3(struct gsm_lchan *lchan, struct msgb *msg, uint16_t chosen_channel)
 { return 0; }
-void bsc_dtap(struct gsm_subscriber_connection *conn, uint8_t link_id, struct msgb *msg) {}
-void bsc_assign_compl(struct gsm_subscriber_connection *conn, uint8_t rr_cause) {}
-void bsc_cm_update(struct gsm_subscriber_connection *conn,
+
+void __real_bsc_dtap(struct gsm_subscriber_connection *conn, uint8_t link_id, struct msgb *msg);
+void __wrap_bsc_dtap(struct gsm_subscriber_connection *conn, uint8_t link_id, struct msgb *msg) {}
+
+void __real_bsc_cm_update(struct gsm_subscriber_connection *conn,
+		   const uint8_t *cm2, uint8_t cm2_len,
+		   const uint8_t *cm3, uint8_t cm3_len);
+void __wrap_bsc_cm_update(struct gsm_subscriber_connection *conn,
 		   const uint8_t *cm2, uint8_t cm2_len,
 		   const uint8_t *cm3, uint8_t cm3_len) {}
+
 const char *osmo_mgcpc_ep_name(const struct osmo_mgcpc_ep *ep)
 {
 	return "fake-ep";
